pub struct PdfDocumentFindPageMatch {
pub page_index: usize,
pub ranges: Vec<PdfTextRange>,
}Available on crate feature
async only.Expand description
One page of a match snapshot emitted by PdfDocumentFindStream.
Fields
page_index: usizeZero-based page index in the searched document.
ranges: Vec<PdfTextRange>Text ranges within that page that belong to the match.